@@ -22,14 +22,14 @@ fn home_dir() -> &'static str {
 }
 
 pub fn expanduser(path: &str) -> String {
-    if path.starts_with("~/") {
-        format!("{}/{}", home_dir(), &path[2..])
+    if let Some(stripped) = path.strip_prefix("~/") {
+        format!("{}/{}", home_dir(), stripped)
     } else {
         path.to_string()
     }
 }
 
-#[derive(Debug, Deserialize)]
+#[derive(Debug, Default, Deserialize)]
 pub struct Settings {
     #[serde(default)]
     pub shell: Option<String>,
@@ -66,14 +66,14 @@ impl Settings {
     pub fn get_kube_configs_paths(&self) -> Result<HashSet<PathBuf>> {
         let mut paths = HashSet::new();
         for inc in &self.configs.include {
-            let expanded = expanduser(&inc);
+            let expanded = expanduser(inc);
             for entry in glob(&expanded)? {
                 paths.insert(entry?);
             }
         }
 
         for exc in &self.configs.exclude {
-            let expanded = expanduser(&exc);
+            let expanded = expanduser(exc);
             for entry in glob(&expanded)? {
                 paths.remove(&entry?);
             }
@@ -83,17 +83,6 @@ impl Settings {
     }
 }
 
-impl Default for Settings {
-    fn default() -> Self {
-        Settings {
-            shell: Default::default(),
-            configs: Configs::default(),
-            prompt: Prompt::default(),
-            behavior: Behavior::default(),
-        }
-    }
-}
-
 #[derive(Debug, Deserialize)]
 pub struct Configs {
     #[serde(default = "default_include_path")]
